# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'EndpointMonitorStatus',
    'EndpointStatus',
    'MonitorProtocol',
    'ProfileMonitorStatus',
    'ProfileStatus',
    'TrafficRoutingMethod',
]


class EndpointMonitorStatus(str, Enum):
    """
    The monitoring status of the endpoint.
    """
    CHECKING_ENDPOINT = "CheckingEndpoint"
    ONLINE = "Online"
    DEGRADED = "Degraded"
    DISABLED = "Disabled"
    INACTIVE = "Inactive"
    STOPPED = "Stopped"


class EndpointStatus(str, Enum):
    """
    The status of the endpoint. If the endpoint is Enabled, it is probed for endpoint health and is included in the traffic routing method.
    """
    ENABLED = "Enabled"
    DISABLED = "Disabled"


class MonitorProtocol(str, Enum):
    """
    The protocol (HTTP, HTTPS or TCP) used to probe for endpoint health.
    """
    HTTP = "HTTP"
    HTTPS = "HTTPS"
    TCP = "TCP"


class ProfileMonitorStatus(str, Enum):
    """
    The profile-level monitoring status of the Traffic Manager profile.
    """
    CHECKING_ENDPOINTS = "CheckingEndpoints"
    ONLINE = "Online"
    DEGRADED = "Degraded"
    DISABLED = "Disabled"
    INACTIVE = "Inactive"


class ProfileStatus(str, Enum):
    """
    The status of the Traffic Manager profile.
    """
    ENABLED = "Enabled"
    DISABLED = "Disabled"


class TrafficRoutingMethod(str, Enum):
    """
    The traffic routing method of the Traffic Manager profile.
    """
    PERFORMANCE = "Performance"
    PRIORITY = "Priority"
    WEIGHTED = "Weighted"
    GEOGRAPHIC = "Geographic"
