# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'SkuTier',
]


class SkuTier(str, Enum):
    """
    The name of the Azure pricing tier to which the SKU applies.
    """
    DEVELOPMENT = "Development"
    BASIC = "Basic"
    STANDARD = "Standard"
