# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from ... import _utilities
from . import outputs

__all__ = [
    'GetSqlVulnerabilityAssessmentBaselineRuleResult',
    'AwaitableGetSqlVulnerabilityAssessmentBaselineRuleResult',
    'get_sql_vulnerability_assessment_baseline_rule',
    'get_sql_vulnerability_assessment_baseline_rule_output',
]

@pulumi.output_type
class GetSqlVulnerabilityAssessmentBaselineRuleResult:
    """
    Rule results.
    """
    def __init__(__self__, id=None, name=None, properties=None, type=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if properties and not isinstance(properties, dict):
            raise TypeError("Expected argument 'properties' to be a dict")
        pulumi.set(__self__, "properties", properties)
        if type and not isinstance(type, str):
            raise TypeError("Expected argument 'type' to be a str")
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        Resource Id
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Resource name
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def properties(self) -> 'outputs.RuleResultsPropertiesResponse':
        """
        Rule results properties.
        """
        return pulumi.get(self, "properties")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Resource type
        """
        return pulumi.get(self, "type")


class AwaitableGetSqlVulnerabilityAssessmentBaselineRuleResult(GetSqlVulnerabilityAssessmentBaselineRuleResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetSqlVulnerabilityAssessmentBaselineRuleResult(
            id=self.id,
            name=self.name,
            properties=self.properties,
            type=self.type)


def get_sql_vulnerability_assessment_baseline_rule(resource_id: Optional[str] = None,
                                                   rule_id: Optional[str] = None,
                                                   workspace_id: Optional[str] = None,
                                                   opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetSqlVulnerabilityAssessmentBaselineRuleResult:
    """
    Rule results.


    :param str resource_id: The identifier of the resource.
    :param str rule_id: The rule Id.
    :param str workspace_id: The workspace Id.
    """
    __args__ = dict()
    __args__['resourceId'] = resource_id
    __args__['ruleId'] = rule_id
    __args__['workspaceId'] = workspace_id
    if opts is None:
        opts = pulumi.InvokeOptions()
    if opts.version is None:
        opts.version = _utilities.get_version()
    __ret__ = pulumi.runtime.invoke('azure-native:security/v20200701preview:getSqlVulnerabilityAssessmentBaselineRule', __args__, opts=opts, typ=GetSqlVulnerabilityAssessmentBaselineRuleResult).value

    return AwaitableGetSqlVulnerabilityAssessmentBaselineRuleResult(
        id=__ret__.id,
        name=__ret__.name,
        properties=__ret__.properties,
        type=__ret__.type)


@_utilities.lift_output_func(get_sql_vulnerability_assessment_baseline_rule)
def get_sql_vulnerability_assessment_baseline_rule_output(resource_id: Optional[pulumi.Input[str]] = None,
                                                          rule_id: Optional[pulumi.Input[str]] = None,
                                                          workspace_id: Optional[pulumi.Input[str]] = None,
                                                          opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetSqlVulnerabilityAssessmentBaselineRuleResult]:
    """
    Rule results.


    :param str resource_id: The identifier of the resource.
    :param str rule_id: The rule Id.
    :param str workspace_id: The workspace Id.
    """
    ...
