# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .get_support_plan_type import *
from .support_plan_type import *

# Make subpackages available:
if typing.TYPE_CHECKING:
    import pulumi_azure_native.addons.v20170515 as __v20170515
    v20170515 = __v20170515
    import pulumi_azure_native.addons.v20180301 as __v20180301
    v20180301 = __v20180301
else:
    v20170515 = _utilities.lazy_import('pulumi_azure_native.addons.v20170515')
    v20180301 = _utilities.lazy_import('pulumi_azure_native.addons.v20180301')

