# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'AccessReviewRecurrencePatternType',
    'AccessReviewRecurrenceRangeType',
    'DefaultDecisionType',
]


class AccessReviewRecurrencePatternType(str, Enum):
    """
    The recurrence type : weekly, monthly, etc.
    """
    WEEKLY = "weekly"
    ABSOLUTE_MONTHLY = "absoluteMonthly"


class AccessReviewRecurrenceRangeType(str, Enum):
    """
    The recurrence range type. The possible values are: endDate, noEnd, numbered.
    """
    END_DATE = "endDate"
    NO_END = "noEnd"
    NUMBERED = "numbered"


class DefaultDecisionType(str, Enum):
    """
    This specifies the behavior for the autoReview feature when an access review completes.
    """
    APPROVE = "Approve"
    DENY = "Deny"
    RECOMMENDATION = "Recommendation"
