# coding=utf-8
# *** WARNING: this file was generated by the Pulumi SDK Generator. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from enum import Enum

__all__ = [
    'ApplicationType',
    'FavoriteType',
    'FlowType',
    'IngestionMode',
    'ItemScope',
    'ItemType',
    'RequestSource',
    'SharedTypeKind',
    'WebTestKind',
]


class ApplicationType(str, Enum):
    """
    Type of application being monitored.
    """
    WEB = "web"
    OTHER = "other"


class FavoriteType(str, Enum):
    """
    Enum indicating if this favorite definition is owned by a specific user or is shared between all users with access to the Application Insights component.
    """
    SHARED = "shared"
    USER = "user"


class FlowType(str, Enum):
    """
    Used by the Application Insights system to determine what kind of flow this component was created by. This is to be set to 'Bluefield' when creating/updating a component via the REST API.
    """
    BLUEFIELD = "Bluefield"


class IngestionMode(str, Enum):
    """
    Indicates the flow of the ingestion.
    """
    APPLICATION_INSIGHTS = "ApplicationInsights"
    APPLICATION_INSIGHTS_WITH_DIAGNOSTIC_SETTINGS = "ApplicationInsightsWithDiagnosticSettings"
    LOG_ANALYTICS = "LogAnalytics"


class ItemScope(str, Enum):
    """
    Enum indicating if this item definition is owned by a specific user or is shared between all users with access to the Application Insights component.
    """
    SHARED = "shared"
    USER = "user"


class ItemType(str, Enum):
    """
    Enum indicating the type of the Analytics item.
    """
    QUERY = "query"
    FUNCTION = "function"
    FOLDER = "folder"
    RECENT = "recent"


class RequestSource(str, Enum):
    """
    Describes what tool created this Application Insights component. Customers using this API should set this to the default 'rest'.
    """
    REST = "rest"


class SharedTypeKind(str, Enum):
    """
    Enum indicating if this workbook definition is owned by a specific user or is shared between all users with access to the Application Insights component.
    """
    SHARED = "shared"
    USER = "user"


class WebTestKind(str, Enum):
    """
    The kind of web test this is, valid choices are ping and multistep.
    """
    PING = "ping"
    MULTISTEP = "multistep"
